@@ -9,10 +9,17 @@ use SQL::ReservedWords::MySQL();
 
 use Rose::DB;
 
-our $VERSION = '0.731';
+our $VERSION = '0.732';
 
 our $Debug = 0;
 
+use Rose::Class::MakeMethods::Generic
+(
+  inheritable_scalar => 'supports_schema',
+);
+
+__PACKAGE__->supports_schema(1);
+
 #
 # Object methods
 #
@@ -39,7 +46,6 @@ sub mysql_auto_reconnect { shift->dbh_attribute_boolean('mysql_auto_reconnect',
 sub mysql_enable_utf8    { shift->dbh_attribute_boolean('mysql_enable_utf8', @_) }
 sub mysql_use_result     { shift->dbh_attribute_boolean('mysql_use_result', @_) }
 
-
 sub dbh_attributes { qw(mysql_auto_reconnect mysql_use_result mysql_enable_utf8) }
 
 sub database_version
