@@ -8,7 +8,7 @@ use SQL::ReservedWords::PostgreSQL();
 
 use Rose::DB;
 
-our $VERSION = '0.732';
+our $VERSION = '0.733';
 
 our $Debug = 0;
 
@@ -362,6 +362,11 @@ sub refine_dbi_column_info
     $col_info->{'pg_type'} =~ /^time(?:\((\d+)\))? without time zone$/i;
     $col_info->{'TIME_SCALE'} = $1 || 0;
   }
+  elsif($type_name eq 'double precision')
+  {
+    $col_info->{'COLUMN_SIZE'} = undef;
+  }
+
 
   # Pg does not populate COLUMN_SIZE correctly for bit fields, so
   # we have to extract the number of bits from pg_type.
@@ -424,8 +429,9 @@ sub parse_dbi_column_info_default
       my $default = $1;
 
       # Single quotes are backslash-escaped, but Postgres 8.1 and
-      # later uses doubled quotes '' instead.
-      if($pg_vers >= 80100 && index($default, q('')) > 0)
+      # later uses doubled quotes '' instead.  Strangely, I see
+      # doubled quotes in 8.0.x as well...
+      if($pg_vers >= 80000 && index($default, q('')) > 0)
       {
         $default =~ s/''/'/g;
       }
